// Copyright (c) ShapeTheCube (www.shapethecube.net) @ Atoru

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Economy;
    using Eco.Gameplay.Housing;
    using Eco.Gameplay.Interactions;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Minimap;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Gameplay.Pipes.LiquidComponents;
    using Eco.Gameplay.Pipes.Gases;
    using Eco.Gameplay.Systems.Tooltip;
    using Eco.Shared;
    using Eco.Shared.Math;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Shared.Items;
    using Eco.Gameplay.Pipes;
    using Eco.World.Blocks;

    // level 1 Item Crate
    [Serialized]    
    [RequireComponent(typeof(AttachmentComponent))]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]                
    [RequireComponent(typeof(LinkComponent))]                   
    public partial class ItemCrateAObject : WorldObject
    {
        public override string FriendlyName { get { return ItemCrateConfig.ITEM_CRATE_NAME_A; } } 
        protected override void Initialize()
        {
            this.GetComponent<MinimapComponent>().Initialize("Storage");                                 
        }
        public override void Destroy()
        {
            base.Destroy();
        }
    }

    [Serialized]
    public partial class ItemCrateAItem : WorldObjectItem<ItemCrateAObject>
    {
        public override string FriendlyName { get { return ItemCrateConfig.ITEM_CRATE_NAME_A; } } 
        public override string Description { get { return ItemCrateConfig.ITEM_CRATE_INFO_A; } }

        static ItemCrateAItem()
        {
            
        }
        
    }

    [RequiresSkill(typeof(LumberWoodworkingSkill), 1)]
    public partial class ItemCrateARecipe : Recipe
    {
        public ItemCrateARecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<ItemCrateAItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<LogItem>(typeof(WoodworkingEfficiencySkill), 15, WoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<HewnLogItem>(typeof(WoodworkingEfficiencySkill), 9, WoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<WoodPulpItem>(typeof(BasicCraftingEfficiencySkill), 78, BasicCraftingEfficiencySkill.MultiplicativeStrategy),
            };
            SkillModifiedValue value = new SkillModifiedValue(2, LumberWoodworkingSkill.MultiplicativeStrategy, typeof(LumberWoodworkingSkill), "craft time");
            SkillModifiedValueManager.AddBenefitForObject(typeof(ItemCrateARecipe), Item.Get<ItemCrateAItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<ItemCrateAItem>().UILink(), value);
            this.CraftMinutes = value;
            this.Initialize(ItemCrateConfig.ITEM_CRATE_NAME_A, typeof(ItemCrateARecipe));
            CraftingComponent.AddRecipe(typeof(WorkbenchObject), this);
        }
    }
    // level 2 Item Crate
    [Serialized]
    [RequireComponent(typeof(AttachmentComponent))]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]
    [RequireComponent(typeof(LinkComponent))]
    public partial class ItemCrateBObject : WorldObject
    {
        public override string FriendlyName { get { return ItemCrateConfig.ITEM_CRATE_NAME_B; } }
        protected override void Initialize()
        {
            this.GetComponent<MinimapComponent>().Initialize("Storage");
        }
        public override void Destroy()
        {
            base.Destroy();
        }
    }

    [Serialized]
    public partial class ItemCrateBItem : WorldObjectItem<ItemCrateBObject>
    {
        public override string FriendlyName { get { return ItemCrateConfig.ITEM_CRATE_NAME_B; } }
        public override string Description { get { return ItemCrateConfig.ITEM_CRATE_INFO_B; } }

        static ItemCrateBItem()
        {

        }

    }

    [RequiresSkill(typeof(LumberWoodworkingSkill), 2)]
    public partial class ItemCrateBRecipe : Recipe
    {
        public ItemCrateBRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<ItemCrateBItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<HewnLogItem>(typeof(LumberWoodworkingEfficiencySkill), 17, LumberWoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<BoardItem>(typeof(WoodworkingEfficiencySkill), 13, WoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<WoodPulpItem>(typeof(BasicCraftingEfficiencySkill), 165, BasicCraftingEfficiencySkill.MultiplicativeStrategy),
            };
            SkillModifiedValue value = new SkillModifiedValue(2, LumberWoodworkingSkill.MultiplicativeStrategy, typeof(LumberWoodworkingSkill), "craft time");
            SkillModifiedValueManager.AddBenefitForObject(typeof(ItemCrateBRecipe), Item.Get<ItemCrateBItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<ItemCrateBItem>().UILink(), value);
            this.CraftMinutes = value;
            this.Initialize(ItemCrateConfig.ITEM_CRATE_NAME_B, typeof(ItemCrateBRecipe));
            CraftingComponent.AddRecipe(typeof(CarpentryTableObject), this);
        }
    }
    // level 3 Item Crate
    [Serialized]
    [RequireComponent(typeof(AttachmentComponent))]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]
    [RequireComponent(typeof(LinkComponent))]
    public partial class ItemCrateCObject : WorldObject
    {
        public override string FriendlyName { get { return ItemCrateConfig.ITEM_CRATE_NAME_C; } }
        protected override void Initialize()
        {
            this.GetComponent<MinimapComponent>().Initialize("Storage");
        }
        public override void Destroy()
        {
            base.Destroy();
        }
    }

    [Serialized]
    public partial class ItemCrateCItem : WorldObjectItem<ItemCrateCObject>
    {
        public override string FriendlyName { get { return ItemCrateConfig.ITEM_CRATE_NAME_C; } }
        public override string Description { get { return ItemCrateConfig.ITEM_CRATE_INFO_C; } }

        static ItemCrateCItem()
        {

        }

    }

    [RequiresSkill(typeof(LumberWoodworkingSkill), 3)]
    public partial class ItemCrateCRecipe : Recipe
    {
        public ItemCrateCRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<ItemCrateCItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<LumberItem>(typeof(LumberWoodworkingEfficiencySkill), 16, LumberWoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<BoardItem>(typeof(LumberWoodworkingEfficiencySkill), 33, LumberWoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<IronIngotItem>(typeof(LumberWoodworkingEfficiencySkill), 6, LumberWoodworkingEfficiencySkill.MultiplicativeStrategy),
            };
            SkillModifiedValue value = new SkillModifiedValue(2, LumberWoodworkingSkill.MultiplicativeStrategy, typeof(LumberWoodworkingSkill), "craft time");
            SkillModifiedValueManager.AddBenefitForObject(typeof(ItemCrateCRecipe), Item.Get<ItemCrateCItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<ItemCrateCItem>().UILink(), value);
            this.CraftMinutes = value;
            this.Initialize(ItemCrateConfig.ITEM_CRATE_NAME_C, typeof(ItemCrateCRecipe));
            CraftingComponent.AddRecipe(typeof(SawmillObject), this);
        }
    }
}