// Copyright (c) ShapeTheCube (www.shapethecube.net) @ Atoru

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Economy;
    using Eco.Gameplay.Housing;
    using Eco.Gameplay.Interactions;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Minimap;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Gameplay.Pipes.LiquidComponents;
    using Eco.Gameplay.Pipes.Gases;
    using Eco.Gameplay.Systems.Tooltip;
    using Eco.Shared;
    using Eco.Shared.Math;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Shared.Items;
    using Eco.Gameplay.Pipes;
    using Eco.World.Blocks;

    // level 1 Item Crate
    [Serialized]    
    [RequireComponent(typeof(AttachmentComponent))]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]                
    [RequireComponent(typeof(LinkComponent))]                   
    public partial class MixedCrateAObject : WorldObject
    {
        public override string FriendlyName { get { return ItemCrateConfig.MIXED_CRATE_NAME_A; } } 
        protected override void Initialize()
        {
            this.GetComponent<MinimapComponent>().Initialize("Storage");                                 
        }
        public override void Destroy()
        {
            base.Destroy();
        }
    }

    [Serialized]
    public partial class MixedCrateAItem : WorldObjectItem<MixedCrateAObject>
    {
        public override string FriendlyName { get { return ItemCrateConfig.MIXED_CRATE_NAME_A; } } 
        public override string Description { get { return ItemCrateConfig.MIXED_CRATE_INFO_A; } }

        static MixedCrateAItem()
        {
            
        }
        
    }

    [RequiresSkill(typeof(LumberWoodworkingSkill), 1)]
    public partial class MixedCrateARecipe : Recipe
    {
        public MixedCrateARecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<MixedCrateAItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<LogItem>(typeof(WoodworkingEfficiencySkill), 35, WoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<HewnLogItem>(typeof(WoodworkingEfficiencySkill), 16, WoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<WoodPulpItem>(typeof(BasicCraftingEfficiencySkill), 85, BasicCraftingEfficiencySkill.MultiplicativeStrategy),
            };
            SkillModifiedValue value = new SkillModifiedValue(2, LumberWoodworkingSkill.MultiplicativeStrategy, typeof(LumberWoodworkingSkill), "craft time");
            SkillModifiedValueManager.AddBenefitForObject(typeof(MixedCrateARecipe), Item.Get<MixedCrateAItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<MixedCrateAItem>().UILink(), value);
            this.CraftMinutes = value;
            this.Initialize(ItemCrateConfig.MIXED_CRATE_NAME_A, typeof(MixedCrateARecipe));
            CraftingComponent.AddRecipe(typeof(WorkbenchObject), this);
        }
    }
    // level 2 Item Crate
    [Serialized]
    [RequireComponent(typeof(AttachmentComponent))]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]
    [RequireComponent(typeof(LinkComponent))]
    public partial class MixedCrateBObject : WorldObject
    {
        public override string FriendlyName { get { return ItemCrateConfig.MIXED_CRATE_NAME_B; } }
        protected override void Initialize()
        {
            this.GetComponent<MinimapComponent>().Initialize("Storage");
        }
        public override void Destroy()
        {
            base.Destroy();
        }
    }

    [Serialized]
    public partial class MixedCrateBItem : WorldObjectItem<MixedCrateBObject>
    {
        public override string FriendlyName { get { return ItemCrateConfig.MIXED_CRATE_NAME_B; } }
        public override string Description { get { return ItemCrateConfig.MIXED_CRATE_INFO_B; } }

        static MixedCrateBItem()
        {

        }

    }

    [RequiresSkill(typeof(LumberWoodworkingSkill), 2)]
    public partial class MixedCrateBRecipe : Recipe
    {
        public MixedCrateBRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<MixedCrateBItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<HewnLogItem>(typeof(LumberWoodworkingEfficiencySkill), 35, LumberWoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<BoardItem>(typeof(WoodworkingEfficiencySkill), 32, WoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<WoodPulpItem>(typeof(BasicCraftingEfficiencySkill), 142, BasicCraftingEfficiencySkill.MultiplicativeStrategy),
            };
            SkillModifiedValue value = new SkillModifiedValue(2, LumberWoodworkingSkill.MultiplicativeStrategy, typeof(LumberWoodworkingSkill), "craft time");
            SkillModifiedValueManager.AddBenefitForObject(typeof(MixedCrateBRecipe), Item.Get<MixedCrateBItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<MixedCrateBItem>().UILink(), value);
            this.CraftMinutes = value;
            this.Initialize(ItemCrateConfig.MIXED_CRATE_NAME_B, typeof(MixedCrateBRecipe));
            CraftingComponent.AddRecipe(typeof(CarpentryTableObject), this);
        }
    }
    // level 3 Item Crate
    [Serialized]
    [RequireComponent(typeof(AttachmentComponent))]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]
    [RequireComponent(typeof(LinkComponent))]
    public partial class MixedCrateCObject : WorldObject
    {
        public override string FriendlyName { get { return ItemCrateConfig.MIXED_CRATE_NAME_C; } }
        protected override void Initialize()
        {
            this.GetComponent<MinimapComponent>().Initialize("Storage");
        }
        public override void Destroy()
        {
            base.Destroy();
        }
    }

    [Serialized]
    public partial class MixedCrateCItem : WorldObjectItem<MixedCrateCObject>
    {
        public override string FriendlyName { get { return ItemCrateConfig.MIXED_CRATE_NAME_C; } }
        public override string Description { get { return ItemCrateConfig.MIXED_CRATE_INFO_C; } }

        static MixedCrateCItem()
        {

        }

    }

    [RequiresSkill(typeof(LumberWoodworkingSkill), 3)]
    public partial class MixedCrateCRecipe : Recipe
    {
        public MixedCrateCRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<MixedCrateCItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<LumberItem>(typeof(LumberWoodworkingEfficiencySkill), 33, LumberWoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<BoardItem>(typeof(LumberWoodworkingEfficiencySkill), 65, LumberWoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<IronIngotItem>(typeof(LumberWoodworkingEfficiencySkill), 13, LumberWoodworkingEfficiencySkill.MultiplicativeStrategy),
            };
            SkillModifiedValue value = new SkillModifiedValue(2, LumberWoodworkingSkill.MultiplicativeStrategy, typeof(LumberWoodworkingSkill), "craft time");
            SkillModifiedValueManager.AddBenefitForObject(typeof(MixedCrateCRecipe), Item.Get<MixedCrateCItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<MixedCrateCItem>().UILink(), value);
            this.CraftMinutes = value;
            this.Initialize(ItemCrateConfig.MIXED_CRATE_NAME_C, typeof(MixedCrateCRecipe));
            CraftingComponent.AddRecipe(typeof(SawmillObject), this);
        }
    }
}