// Copyright (c) ShapeTheCube (www.shapethecube.net) @ Atoru

namespace Eco.Mods.TechTree
{
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Shared.Serialization;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Mods.TechTree;

    // level 1 Item Crate
    [RequireComponent(typeof(PublicStorageComponent))]
    public partial class MixedCrateAObject : WorldObject
    {
        protected override void PostInitialize()
        {
            base.PostInitialize();

            var storage = this.GetComponent<PublicStorageComponent>();
            // set storage slots and weight limit
            if (ItemCrateConfig.MIXED_CRATE_WEIGHT_A == 0)
            {
                storage.Initialize(ItemCrateConfig.MIXED_CRATE_SLOT_A);  // no weight limit
            }
            else
            {
                storage.Initialize(ItemCrateConfig.MIXED_CRATE_SLOT_A, ItemCrateConfig.MIXED_CRATE_WEIGHT_A * 1000000); // apply weight limit
            }
            // inventory item types (items | carried | mixed)
            if (ItemCrateConfig.MIXED_CRATE_TYPE_A != "mixed")
            {
                if (ItemCrateConfig.MIXED_CRATE_TYPE_A == "items")
                {
                    storage.Storage.AddRestriction(new NotCarriedRestriction()); // restrict container to items only.
                }
                else if (ItemCrateConfig.MIXED_CRATE_TYPE_A == "carried")
                {
                    storage.Storage.AddRestriction(new CarriedRestriction()); // restrict container to carried items only.
                }
            }
            this.GetComponent<PropertyAuthComponent>().Initialize(AuthModeType.Inherited);
            this.GetComponent<LinkComponent>().Initialize(5);
            this.GetComponent<MinimapComponent>().Initialize("Storage");
        }
    }
    // level 2 Item Crate
    [RequireComponent(typeof(PublicStorageComponent))]
    public partial class MixedCrateBObject : WorldObject
    {
        protected override void PostInitialize()
        {
            base.PostInitialize();

            var storage = this.GetComponent<PublicStorageComponent>();
            // set storage slots and weight limit
            if (ItemCrateConfig.MIXED_CRATE_WEIGHT_B == 0)
            {
                storage.Initialize(ItemCrateConfig.MIXED_CRATE_SLOT_B);  // no weight limit
            }
            else
            {
                storage.Initialize(ItemCrateConfig.MIXED_CRATE_SLOT_B, ItemCrateConfig.MIXED_CRATE_WEIGHT_B * 1000000); // apply weight limit
            }
            // inventory item types (items | carried | mixed)
            if (ItemCrateConfig.MIXED_CRATE_TYPE_B != "mixed")
            {
                if (ItemCrateConfig.MIXED_CRATE_TYPE_B == "items")
                {
                    storage.Storage.AddRestriction(new NotCarriedRestriction()); // restrict container to items only.
                }
                else if (ItemCrateConfig.MIXED_CRATE_TYPE_B == "carried")
                {
                    storage.Storage.AddRestriction(new CarriedRestriction()); // restrict container to carried items only.
                }
            }
            this.GetComponent<PropertyAuthComponent>().Initialize(AuthModeType.Inherited);
            this.GetComponent<LinkComponent>().Initialize(5);
            this.GetComponent<MinimapComponent>().Initialize("Storage");
        }
    }
    // level 3 Item Crate
    [RequireComponent(typeof(PublicStorageComponent))]
    public partial class MixedCrateCObject : WorldObject
    {
        protected override void PostInitialize()
        {
            base.PostInitialize();

            var storage = this.GetComponent<PublicStorageComponent>();
            // set storage slots and weight limit
            if (ItemCrateConfig.MIXED_CRATE_WEIGHT_C == 0)
            {
                storage.Initialize(ItemCrateConfig.MIXED_CRATE_SLOT_C);  // no weight limit
            }
            else
            {
                storage.Initialize(ItemCrateConfig.MIXED_CRATE_SLOT_C, ItemCrateConfig.MIXED_CRATE_WEIGHT_C * 1000000); // apply weight limit
            }
            // inventory item types (items | carried | mixed)
            if (ItemCrateConfig.MIXED_CRATE_TYPE_C != "mixed")
            {
                if (ItemCrateConfig.MIXED_CRATE_TYPE_C == "items")
                {
                    storage.Storage.AddRestriction(new NotCarriedRestriction()); // restrict container to items only.
                }
                else if (ItemCrateConfig.MIXED_CRATE_TYPE_C == "carried")
                {
                    storage.Storage.AddRestriction(new CarriedRestriction()); // restrict container to carried items only.
                }
            }
            this.GetComponent<PropertyAuthComponent>().Initialize(AuthModeType.Inherited);
            this.GetComponent<LinkComponent>().Initialize(5);
            this.GetComponent<MinimapComponent>().Initialize("Storage");
        }
    }
}
